package ru.ulstu.admin.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.admin.model.AspirantForm;
import ru.ulstu.admin.service.AdminAspirantService;
import ru.ulstu.aspirant.model.Aspirant;
import ru.ulstu.indicator.model.Course;

@Controller
@RequestMapping("admin")
public class AdminAspirantController {
    private final AdminAspirantService adminAspirantService;

    public AdminAspirantController(AdminAspirantService adminAspirantService) {
        this.adminAspirantService = adminAspirantService;
    }

    @GetMapping("aspirants")
    public String getListOfAspirants(Model model) {
        model.addAttribute("aspirants", adminAspirantService.getAspirants());
        return "admin/aspirantsList";
    }

    @GetMapping("/editAspirant/{aspirantId}")
    public String editAspirant(@PathVariable(value = "aspirantId") Integer id, Model model) {
        model.addAttribute("aspirant",
                new AspirantForm((id != null && id != 0)
                        ? adminAspirantService.getAspirantById(id)
                        : new Aspirant()));
        model.addAttribute("courses", Course.values());
        model.addAttribute("managers", adminAspirantService.getManagers());
        return "admin/editAspirant";
    }

    @PostMapping(value = "saveAspirant", params = "save")
    public String saveAspirant(AspirantForm aspirantForm, Model model) {
        adminAspirantService.saveAspirant(aspirantForm);
        return "redirect:/admin/aspirants";
    }

    @PostMapping(value = "saveAspirant", params = "delete")
    public String deleteIndicator(AspirantForm aspirantForm, Model model) {
        adminAspirantService.deleteAspirant(aspirantForm);
        return "redirect:/admin/aspirants";
    }
}
