package ru.ulstu.indicator.service;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import ru.ulstu.admin.model.IndicatorForm;
import ru.ulstu.indicator.model.Course;
import ru.ulstu.indicator.model.Indicator;
import ru.ulstu.indicator.repository.IndicatorRepository;

import java.util.List;

@Service
public class IndicatorService {
    private final IndicatorRepository indicatorRepository;

    public IndicatorService(IndicatorRepository indicatorRepository) {
        this.indicatorRepository = indicatorRepository;
    }

    public List<Indicator> getIndicatorList() {
        return indicatorRepository.findAll();
    }

    public void save(Indicator indicator) {
        indicatorRepository.save(indicator);
    }

    public Indicator findByName(String name) {
        return indicatorRepository.findByName(name);
    }

    public Indicator getIndicatorById(Integer id) {
        return indicatorRepository.findById(id).orElseThrow(() -> new RuntimeException("Indicator not found"));
    }

    public void deleteIndicator(IndicatorForm indicatorForm) {
        indicatorRepository.deleteById(indicatorForm.getId());
    }

    public List<Indicator> getIndicatorsByCourse(Course course) {
        return indicatorRepository.findAllByCourse(course);
    }

    public Page<Indicator> getIndicatorsByCourse(Pageable pageable) {
        return indicatorRepository.findAll(pageable);
    }
}
